@@ -21,6 +21,15 @@ class IRERPortletAdvancedStatic(static.IStaticPortlet):
     """
     A custom static text portlet
     """
+
+    target_attr = schema.Bool(
+        title=_(u"Open links in a new window"),
+        description=_(u"Tick this box if you want to open the header "
+            "and footer links in a new window"),
+        required=False,
+        default=False
+        )
+
     text = schema.Text(
         title=_(u"Text"),
         description=_(u"The text to render"),
@@ -32,6 +41,10 @@ class IRERPortletAdvancedStatic(static.IStaticPortlet):
                                 source=SearchableTextSourceBinder({'object_provides': IATImage.__identifier__},
                                                                     default_query='path:'))
 
+    image_ref_height = schema.Int(title=_(u"Background image height"),
+                                description=_(u"Specify image background's height (in pixels). If empty will be used image's height."),
+                                required=False)
+
     internal_url = schema.Choice(title=_(u"Internal link"),
                                 description=_(u"Insert an internal link. This field override external link field"),
                                 required=False,
@@ -56,21 +69,25 @@ class Assignment(static.Assignment):
 
     implements(IRERPortletAdvancedStatic)
 
+    target_attr = False
     image_ref = ''
+    image_ref_height = None
     assignment_context_path = None
     internal_url = ''
     portlet_class = ''
     css_style = ''
 
     def __init__(self, header=u"", text=u"", omit_border=False, footer=u"",
-                 more_url='', hide=False, assignment_context_path=None,
-                 image_ref='', internal_url='', portlet_class='', css_style=''):
+                 more_url='', target_attr=False, hide=False, assignment_context_path=None,
+                 image_ref='', image_ref_height=None, internal_url='', portlet_class='', css_style=''):
         self.header = header
         self.text = text
         self.omit_border = omit_border
         self.footer = footer
         self.more_url = more_url
+        self.target_attr = target_attr
         self.image_ref = image_ref
+        self.image_ref_height = image_ref_height
         self.assignment_context_path = assignment_context_path
         self.internal_url = internal_url
         self.portlet_class = portlet_class
@@ -127,6 +144,10 @@ class Renderer(static.Renderer):
         image = self.getImageObject(self.data.image_ref)
         if not image:
             return ""
+        # compatibility with dexterity images
+        blobimage = getattr(image, 'image', None)
+        if blobimage:
+            return blobimage.getImageSize()[1]
         return str(image.getImage().height)
 
     def getImageStyle(self):
@@ -140,10 +161,16 @@ class Renderer(static.Renderer):
             return ''
         elif portlet_image == 'new':
             img_url = self.getImgUrl()
-            height = self.getImgHeight()
+            if self.data.image_ref_height:
+                height = self.data.image_ref_height
+            else:
+                height = self.getImgHeight()
         elif portlet_image == 'old':
             img_url = self.getOldImgUrl()
-            height = self.getOldImgHeight()
+            if self.data.image_ref_height:
+                height = self.data.image_ref_height
+            else:
+                height = self.getOldImgHeight()
 
         style = "background-image:url(%s)" % img_url
         if height:
@@ -157,7 +184,7 @@ class Renderer(static.Renderer):
         """
         if self.data.image_ref:
             return 'new'
-        image_old = getattr(self.data, 'image', None)
+        image_old = getattr(self.data.aq_base, 'image', None)
         if image_old:
             return 'old'
         return ''
@@ -196,6 +223,12 @@ class Renderer(static.Renderer):
         else:
             return self.data.more_url or ""
 
+    def getLinkTitle(self):
+        if self.data.target_attr:
+            return _(u'Opens in a new window')
+        else:
+            return ''
+
 
 class AddForm(static.AddForm):
     """Portlet add form.
